.. include:: ../README.rst


.. toctree::
   :maxdepth: 1
   :hidden:

   installation
   tutorials/index
   development

.. toctree::
   :maxdepth: 1
   :caption: Package Reference
   :hidden:

   astir
   astir.data
   astir.models


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
